
TODO_94_66_41_94: Split `argrelay.server.yaml` into: `argrelay.plugins.yaml` and `argrelay.server.yaml`.
Or at least make it less confusing
(because client-side still uses `argrelay.server.yaml` to use plugin configuration on server response).
It should be called `argrelay.plugins.yaml` which is exactly the part seen and
reused by both server and client, right?

FS_36_17_84_44: Make it possible for check_script to verify whether there is any issues between:
*   client-side plugin config
*   server-side plugin config

Make sure there is a way to employ `reusable_config_data` (if files are split) -
repeating the same data is not convenient.
